Class: Google::Apis::ManufacturersV1::Product

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/manufacturers_v1/classes.rb,
lib/google/apis/manufacturers_v1/representations.rb,
lib/google/apis/manufacturers_v1/representations.rb

Overview

Product data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Product

Returns a new instance of Product.



1191
1192
1193
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesGoogle::Apis::ManufacturersV1::Attributes

Attributes of the product. For more information, see https://support.google. com/manufacturers/answer/6124116. Corresponds to the JSON property attributes



1141
1142
1143
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1141

def attributes
  @attributes
end

#content_languageString

The content language of the product as a two-letter ISO 639-1 language code ( for example, en). Corresponds to the JSON property contentLanguage

Returns:

  • (String)


1147
1148
1149
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1147

def content_language
  @content_language
end

#destination_statusesArray<Google::Apis::ManufacturersV1::DestinationStatus>

The status of the destinations. Corresponds to the JSON property destinationStatuses



1152
1153
1154
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1152

def destination_statuses
  @destination_statuses
end

#feed_labelString

Optional. The feed label for the product. Corresponds to the JSON property feedLabel

Returns:

  • (String)


1157
1158
1159
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1157

def feed_label
  @feed_label
end

#issuesArray<Google::Apis::ManufacturersV1::Issue>

A server-generated list of issues associated with the product. Corresponds to the JSON property issues



1162
1163
1164
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1162

def issues
  @issues
end

#nameString

Name in the format target_country`:`content_language`:`product_id. target_country - The target country of the product as a CLDR territory code ( for example, US). content_language - The content language of the product as a two-letter ISO 639-1 language code (for example, en). product_id - The ID of the product. For more information, see https://support.google.com/ manufacturers/answer/6124116#id. Corresponds to the JSON property name

Returns:

  • (String)


1172
1173
1174
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1172

def name
  @name
end

#parentString

Parent ID in the format accounts/account_id`.account_id- The ID of the Manufacturer Center account. Corresponds to the JSON propertyparent`

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1178

def parent
  @parent
end

#product_idString

The ID of the product. For more information, see https://support.google.com/ manufacturers/answer/6124116#id. Corresponds to the JSON property productId

Returns:

  • (String)


1184
1185
1186
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1184

def product_id
  @product_id
end

#target_countryString

The target country of the product as a CLDR territory code (for example, US). Corresponds to the JSON property targetCountry

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1189

def target_country
  @target_country
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1196

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @content_language = args[:content_language] if args.key?(:content_language)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @issues = args[:issues] if args.key?(:issues)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @product_id = args[:product_id] if args.key?(:product_id)
  @target_country = args[:target_country] if args.key?(:target_country)
end