Class: Google::Apis::ManufacturersV1::ProductCertification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/manufacturers_v1/classes.rb,
lib/google/apis/manufacturers_v1/representations.rb,
lib/google/apis/manufacturers_v1/representations.rb

Overview

Product certification data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductCertification

Returns a new instance of ProductCertification.



1271
1272
1273
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#brandString

Required. This is the product's brand name. The brand is used to help identify your product. Corresponds to the JSON property brand

Returns:

  • (String)


1217
1218
1219
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1217

def brand
  @brand
end

#certificationArray<Google::Apis::ManufacturersV1::Certification>

Required. A list of certifications to link to the described product. Corresponds to the JSON property certification



1222
1223
1224
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1222

def certification
  @certification
end

#country_codeArray<String>

Optional. A 2-letter country code (ISO 3166-1 Alpha 2). Corresponds to the JSON property countryCode

Returns:

  • (Array<String>)


1227
1228
1229
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1227

def country_code
  @country_code
end

#destination_statusesArray<Google::Apis::ManufacturersV1::DestinationStatus>

Output only. The statuses of the destinations. Corresponds to the JSON property destinationStatuses



1232
1233
1234
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1232

def destination_statuses
  @destination_statuses
end

#issuesArray<Google::Apis::ManufacturersV1::Issue>

Output only. A server-generated list of issues associated with the product. Corresponds to the JSON property issues



1237
1238
1239
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1237

def issues
  @issues
end

#mpnArray<String>

Optional. These are the Manufacturer Part Numbers (MPN). MPNs are used to uniquely identify a specific product among all products from the same manufacturer Corresponds to the JSON property mpn

Returns:

  • (Array<String>)


1244
1245
1246
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1244

def mpn
  @mpn
end

#nameString

Required. The unique name identifier of a product certification Format: accounts/account/languages/language_code/productCertifications/id Where id is a some unique identifier and language_code is a 2-letter ISO 639-1 code of a Shopping supported language according to https://support.google.com/ merchants/answer/160637. Corresponds to the JSON property name

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1253

def name
  @name
end

#product_codeArray<String>

Optional. Another name for GTIN. Corresponds to the JSON property productCode

Returns:

  • (Array<String>)


1258
1259
1260
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1258

def product_code
  @product_code
end

#product_typeArray<String>

Optional. These are your own product categorization system in your product data. Corresponds to the JSON property productType

Returns:

  • (Array<String>)


1264
1265
1266
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1264

def product_type
  @product_type
end

#titleString

Required. This is to clearly identify the product you are certifying. Corresponds to the JSON property title

Returns:

  • (String)


1269
1270
1271
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1269

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/google/apis/manufacturers_v1/classes.rb', line 1276

def update!(**args)
  @brand = args[:brand] if args.key?(:brand)
  @certification = args[:certification] if args.key?(:certification)
  @country_code = args[:country_code] if args.key?(:country_code)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @issues = args[:issues] if args.key?(:issues)
  @mpn = args[:mpn] if args.key?(:mpn)
  @name = args[:name] if args.key?(:name)
  @product_code = args[:product_code] if args.key?(:product_code)
  @product_type = args[:product_type] if args.key?(:product_type)
  @title = args[:title] if args.key?(:title)
end